@@ -30,10 +30,10 @@ use once_cell::sync::OnceCell;
 use walkdir::{DirEntry, WalkDir};
 
 use crate::findings::Findings;
+use crate::findings::ScanError;
 use crate::formats::{Format, PowerShell, Shell};
 use crate::mime_db::MimeDb;
 use crate::parameters::{OutputFormat, ScanOpts};
-use crate::scan_error::ScanError;
 use std::collections::BTreeSet;
 
 mod findings;
@@ -41,7 +41,6 @@ mod formats;
 mod inspectors;
 mod mime_db;
 mod parameters;
-mod scan_error;
 pub(crate) mod string_type;
 
 #[cfg(test)]
@@ -77,7 +76,7 @@ fn main() {
 	trace!("Initialise mimetype database");
 	init_db();
 
-	debug!("Iterating directory: {:?}", args.dirs);
+	debug!("Iterating directory: {:?}", args.dir);
 
 	let extensions = args.extensions();
 	let excludes = args.excluded_extensions();
@@ -90,12 +89,7 @@ fn main() {
 		debug!("Checking files regardless of extensions");
 	}
 
-	let entries = scan_directory(
-		&args.dirs,
-		extensions.as_ref(),
-		excludes.as_ref(),
-		&args.get_scan_opts(),
-	);
+	let entries = scan_directory(&args.dir, extensions.as_ref(), excludes.as_ref(), &args.get_scan_opts());
 
 	if entries.is_none() {
 		// no need to log anything for fatal errors - fif will already have printed something obvious like
@@ -118,7 +112,7 @@ fn main() {
 		.filter(
 			|result| result.is_err() || !result.as_ref().unwrap().valid,
 			// TODO: find a way to trace! the valid files without doing ↓
-			// || if result.as_ref().unwrap().valid { trace!("{:?} is fine", result.as_ref().unwrap().file); false } else { true }
+			// || if result.as_ref().unwrap().valid { trace!("{:?} ok", result.as_ref().unwrap().file); false } else { true }
 		)
 		.collect();
 
@@ -148,7 +142,9 @@ fn main() {
 	let result = match args.output_format {
 		OutputFormat::Sh => Shell::new().write_all(&mut buffered_stdout, &results),
 		OutputFormat::PowerShell => PowerShell::new().write_all(&mut buffered_stdout, &results),
-		OutputFormat::Text => todo!(),
+		#[cfg(feature = "json")]
+		OutputFormat::Json => formats::Json::new().write_all(&mut buffered_stdout, &results),
+		OutputFormat::Text => formats::Text::new().write_all(&mut buffered_stdout, &results),
 	};
 
 	if result.is_err() {
@@ -228,9 +224,7 @@ fn wanted_file(
 }
 
 /// Given a file path, returns its extension, using [`std::path::Path::extension`].
-fn extension_from_path(path: &Path) -> Option<&OsStr> {
-	path.extension()
-}
+fn extension_from_path(path: &Path) -> Option<&OsStr> { path.extension() }
 
 /// Inspects the given entry, returning a [`Findings`] on success and a [`ScanError`] on failure.
 ///
@@ -255,7 +249,7 @@ fn scan_file(entry: &DirEntry) -> Result<Findings, ScanError> {
 	let result = result.unwrap();
 
 	// set of known extensions for the given mimetype
-	let known_exts = inspectors::mime_extension_lookup(result.clone());
+	let known_exts = inspectors::mime_extension_lookup(result.essence_str().into());
 	// file extension for this particular file
 	let entry_ext = extension_from_path(entry.path());
 
