@@ -24,6 +24,9 @@ pub enum OutputFormat {
 	PowerShell,
 	/// Plain text.
 	Text,
+	/// JSON.
+	#[cfg(feature = "json")]
+	Json,
 }
 
 // TODO: convert this to macro style?: https://docs.rs/clap/3.0.0-beta.2/clap/index.html#using-macros
@@ -48,23 +51,37 @@ pub struct Parameters {
 	/// Only examine files with these extensions.
 	/// Multiple extensions can be specified by either using the flag multiple times (`-e jpg -e png -e gif`), or by
 	/// separating them with commas (`-e jpg,png,gif`).
-	#[clap(short, long, use_delimiter = true, require_delimiter = true, value_name = "ext")]
+	#[clap(short, long, use_delimiter = true, require_delimiter = true, value_name = "ext", validator = lowercase_exts)]
 	pub exts: Option<Vec<StringType>>,
 
 	/// Use these preset lists of extensions as the search filter (comma-separated list).
 	/// `media` includes all extensions from the `audio`, `video`, and `images` sets, making `-E media` equivalent to
 	/// `-E audio,video,images`.
-	#[clap(short = 'E', long, arg_enum, use_delimiter = true, require_delimiter = true, value_name = "set")]
+	#[clap(
+		short = 'E',
+		long,
+		arg_enum,
+		use_delimiter = true,
+		require_delimiter = true,
+		value_name = "set"
+	)]
 	pub ext_set: Vec<ExtensionSet>,
 
 	/// Don't scan files with these extensions.
 	/// This option takes precedence over extensions specified with `-e` or `-E`.
-	#[clap(short = 'x', long, use_delimiter = true, require_delimiter = true, value_name = "ext")]
+	#[clap(short = 'x', long, use_delimiter = true, require_delimiter = true, value_name = "ext", validator = lowercase_exts)]
 	pub exclude: Option<Vec<StringType>>,
 
 	/// Exclude files using a preset list of extensions.
 	/// This option takes precedence over extensions specified with `-e` or `-E`.
-	#[clap(short = 'X', long, arg_enum, use_delimiter = true, require_delimiter = true, value_name = "set")]
+	#[clap(
+		short = 'X',
+		long,
+		arg_enum,
+		use_delimiter = true,
+		require_delimiter = true,
+		value_name = "set"
+	)]
 	pub exclude_set: Vec<ExtensionSet>,
 
 	/// Don't skip hidden files and directories.
@@ -98,9 +115,16 @@ pub struct Parameters {
 	pub quiet: u8,
 
 	/// The directory to process.
-	// TODO: right now this can only take a single directory - should this be improved?
 	#[clap(name = "DIR", default_value = ".", parse(from_os_str))]
-	pub dirs: PathBuf,
+	pub dir: PathBuf,
+}
+
+fn lowercase_exts(exts: &str) -> Result<(), String> {
+	// TODO: i would much rather accept uppercase exts and convert them to lowercase than just rejecting lowercase exts...
+	if exts.to_lowercase() != exts {
+		return Err(String::from("Supplied extensions must be lowercase"));
+	}
+	Ok(())
 }
 
 /// Further options relating to scanning.
@@ -189,14 +213,14 @@ impl Parameters {
 		match self.quiet {
 			0 => {
 				match self.verbose {
-					0 => "info", // no verbosity flags specified
+					0 => "info",  // no verbosity flags specified
 					1 => "debug", // -v
-					_ => "trace" // -vv...
+					_ => "trace", // -vv...
 				}
-			},
-			1 => "warn", // -q
+			}
+			1 => "warn",  // -q
 			2 => "error", // -qq
-			_ => "off" // -qqq...
+			_ => "off",   // -qqq...
 		}
 	}
 }
@@ -209,6 +233,7 @@ pub enum ExtensionSet {
 	/// Extensions used for audio file formats, such as `mp3`, `ogg`, `flac`, etc.
 	Audio,
 	/// Extensions used for video file formats, such as `mkv`, `mp4`, `mov`, etc.
+	#[clap(alias = "videos")]
 	Video,
 	/// Extensions used for media file formats. This acts as a combination of the [Images](ExtensionSet::Images),
 	/// [Audio](ExtensionSet::Audio) and [Videos](ExtensionSet::Videos) variants.
