@@ -1,5 +1,5 @@
 use crate::findings::Findings;
-use crate::formats::{Format, Shell};
+use crate::formats::{Format, PowerShell, Shell};
 use crate::inspectors::{mime_extension_lookup, BUF_SIZE};
 use crate::mime_db::MimeDb;
 use crate::string_type::String;
@@ -67,14 +67,16 @@ fn detect_type() {
 /// Ensure that `mime_extension_lookup` works as expected, and that the set of extensions for JPEG, PNG, PDF, and ZIP
 /// contain "jpg", "png", "pdf", and "zip", respectively.
 fn recommend_ext() {
-	assert!(mime_extension_lookup(IMAGE_JPEG)
+	assert!(mime_extension_lookup(IMAGE_JPEG.essence_str().into())
 		.unwrap()
 		.contains(&String::from("jpg")));
-	assert!(mime_extension_lookup(IMAGE_PNG).unwrap().contains(&String::from("png")));
-	assert!(mime_extension_lookup(APPLICATION_PDF)
+	assert!(mime_extension_lookup(IMAGE_PNG.essence_str().into())
+		.unwrap()
+		.contains(&String::from("png")));
+	assert!(mime_extension_lookup(APPLICATION_PDF.essence_str().into())
 		.unwrap()
 		.contains(&String::from("pdf")));
-	assert!(mime_extension_lookup(application_zip())
+	assert!(mime_extension_lookup(application_zip().essence_str().into())
 		.unwrap()
 		.contains(&String::from("zip")));
 }
@@ -116,7 +118,7 @@ fn simple_directory() {
 		follow_symlinks: false,
 	};
 
-	let entries = scan_directory(&dir.path().to_path_buf(), None, None, &scan_opts).expect("Directory scan failed.");
+	let entries = scan_directory(dir.path(), None, None, &scan_opts).expect("Directory scan failed.");
 
 	assert_eq!(entries.len(), files.len());
 
@@ -142,7 +144,7 @@ fn simple_directory() {
 		// check if the recommended extension for this file is in the list of known extensions for its mimetype - for
 		// example, if the file is determined to be an IMAGE_PNG, its recommended extension should be one of the extensions
 		// returned by `mime_extension_lookup(IMAGE_PNG)`.
-		assert!(mime_extension_lookup(result.mime.clone())
+		assert!(mime_extension_lookup(result.mime.essence_str().into())
 			.unwrap()
 			.contains(&result.recommended_extension().unwrap()));
 
@@ -210,7 +212,7 @@ fn argument_parsing() {
 fn positional_args() {
 	for flag in &["-x", "-e", "-X", "-E"] {
 		assert_eq!(
-			Parameters::parse_from(vec!["fif", flag, "images", "directory"]).dirs,
+			Parameters::parse_from(vec!["fif", flag, "images", "directory"]).dir,
 			PathBuf::from("directory")
 		)
 	}
@@ -304,14 +306,15 @@ fn rejects_bad_args() {
 /// Generate random series of bytes and try to identify them. This test makes no assertions and can only fail if the
 /// mime database somehow panics or hangs.
 fn identify_random_bytes() {
+	use rand::RngCore;
 	let db = get_mime_db();
-	let rng = fastrand::Rng::new();
-	let mut bytes: Vec<u8>;
+	let mut rng = rand::thread_rng();
+	let mut bytes: [u8; BUF_SIZE * 2] = [0; BUF_SIZE * 2];
 	let mut results: HashMap<Mime, i32> = HashMap::new();
 
-	for _ in 1..500 {
-		bytes = std::iter::repeat_with(|| rng.u8(..)).take(BUF_SIZE * 2).collect();
-		if let Some(detected_type) = db.get_type(&*bytes) {
+	for _ in 1..1000 {
+		rng.fill_bytes(&mut bytes);
+		if let Some(detected_type) = db.get_type(&bytes) {
 			*results.entry(detected_type).or_insert(0) += 1;
 		}
 	}
@@ -335,21 +338,62 @@ fn outputs_move_commands() {
 		mime: IMAGE_JPEG,
 	})];
 
+	for format in &["Shell", "PowerShell"] {
+		let mut cursor = std::io::Cursor::new(Vec::new());
+		let mut contents = std::string::String::new();
+
+		match *format {
+			"Shell" => Shell::new().write_all(&mut cursor, &entries),
+			"PowerShell" => PowerShell::new().write_all(&mut cursor, &entries),
+			_ => unreachable!(),
+		}
+		.expect("Failed to write to cursor");
+
+		cursor.set_position(0);
+		cursor
+			.read_to_string(&mut contents)
+			.expect("Failed to read from cursor to string");
+
+		// the output should contain a command like "mv -i misnamed_file.png misnamed_file.jpg"
+		assert!(
+			contents.contains("misnamed_file.jpg"),
+			"{} output doesn't contain move command!\n===\n{}",
+			format,
+			contents
+		)
+	}
+}
+
+#[test]
+#[cfg(feature = "json")]
+/// Ensure JSON output is valid.
+fn test_json() {
+	use crate::formats::Json;
+	use std::io::Read;
+	// create an example finding stating that "misnamed_file.png" has been identified as a jpeg file
+	let entries = vec![Ok(Findings {
+		file: Path::new("misnamed_file.png"),
+		valid: false,
+		mime: IMAGE_JPEG,
+	})];
+
 	let mut cursor = std::io::Cursor::new(Vec::new());
 	let mut contents = std::string::String::new();
 
-	Shell::new()
+	Json::new()
 		.write_all(&mut cursor, &entries)
 		.expect("Failed to write to cursor");
+
 	cursor.set_position(0);
 	cursor
 		.read_to_string(&mut contents)
 		.expect("Failed to read from cursor to string");
 
-	// the output should contain a command like "mv -i misnamed_file.png misnamed_file.jpg"
+	// the output should contain the file's mime type
 	assert!(
-		contents.contains("misnamed_file.jpg"),
-		"Output doesn't contain move command!"
+		contents.contains(IMAGE_JPEG.essence_str()),
+		"JSON output doesn't contain move command!\n===\n{}",
+		contents
 	)
 }
 
@@ -391,7 +435,10 @@ fn writables_is_correct() {
 #[test]
 /// Test various combinations of verbosity flags.
 fn verbosity() {
-	assert!(Parameters::try_parse_from(&["fif", "-q", "-v"]).is_err(), "Failed to reject usage of both -q and -v!");
+	assert!(
+		Parameters::try_parse_from(&["fif", "-q", "-v"]).is_err(),
+		"Failed to reject usage of both -q and -v!"
+	);
 
 	let mut expected_results = HashMap::new();
 	expected_results.insert("-qqqqqqqq", "off");
